<template>
	<div class="echarts-wrapper" @click="toParentPage">
		<div class="echarts-content" ref="chart"></div>
	</div>
</template>

<script>
import * as echarts from "echarts";
import {
	onlinegroupVolAnalysis
} from '@/assets/js/api'
export default {
	name: "PictorialBar",
	chart: "",
	chartData: {},
	props: {
		id: {
			type: String,
			default: ""
		}
	},
	data() {
		return {}
	},
	methods: {
		toParentPage() {
			window.parent.parent.postMessage({
				cmd: "syncPage",
				params: {
					pageInfo: {
						label: "电池实时告警",
						name: "batteryrTimequery",
						src: "#/batteryrTimequery",
						closable: true
					},
				}
			}, "*");
		},
		setOption(opt) {
			this.$options.chart.setOption(opt);
		},
		organizeData(data) {
			let option = {
				grid: {
					top: 40,
					right: 20,
					left: 50,
					bottom: 30
				},
				tooltip: {
					trigger: 'axis',
					axisPointer: {
						type: 'shadow'
					},
				},
				legend: {
					data: ['在线电压', '组端电压'],
					top: '4%',
					right: '8%',
					icon: 'rect',
					textStyle: {
						color: '#fff',
					}
				},
				xAxis: {
					type: 'category',
					axisLabel: {
						color: '#fff',
						interval: 0,
					},
					axisLine: {
						lineStyle: {
							color: "#007DD140",
						}
					},
					data: data.xData,
				},
				yAxis: {
					splitLine: {
						lineStyle: {
							color: '#007DD140',
							type: 'dashed',
						}
					}
				},
				series: []
			};

			data.series.map((item) => {
				option.series.push({
					name: item.name,
					type: "pictorialBar",
					symbol: 'path://M0,10 L10,10 C5.5,10 5.5,5 5,0 C4.5,5 4.5,10 0,10 z',
					itemStyle: {
						color: item.color
					},
					data: item.data
				})
			})

			option.series[1]['barGap'] = '-1%'

			// 设置配置项
			this.setOption(option);
		},
		setData(sendData) {
			if (sendData) {
				this.$options.chartData = sendData;
				this.organizeData(sendData)
			} else {
				this.postData()
				setInterval(() => {
					this.postData()
				}, 3000)
			}
		},
		postData() {
			let userId = localStorage.getItem('userId');
			let params = {
				userId: userId
			}
			onlinegroupVolAnalysis(params).then((res) => {
				if (res.data.code == 1) {
					let optionData = {
						xData: [],
						series: [{
							name: "在线电压",
							data: [],
							color: '#E85D22'
						},
						{
							name: "组端电压",
							data: [],
							color: '#2EEA9D'
						}
						]
					}
					let resData = res.data.data;
					for (let key in resData) {
						let seriesData = resData[key]
						if (key == '在线电压') {
							for (let jey in seriesData) {
								if (typeof seriesData[jey] == 'string') {
									optionData.series[0].data.push({
										name: jey,
										value: Number(seriesData[jey].split('%')[0])
									})
								} else {
									optionData.series[0].data.push({
										name: jey,
										value: seriesData[jey]
									})
								}
							}
						} else if (key == '组端电压') {
							for (let jey in seriesData) {
								if (typeof seriesData[jey] == 'string') {
									optionData.series[1].data.push({
										name: jey,
										value: Number(seriesData[jey].split('%')[0])
									})
								} else {
									optionData.series[1].data.push({
										name: jey,
										value: seriesData[jey]
									})
								}
							}
						}
					}
					this.$options.chartData = optionData;
					this.organizeData(optionData)
				}
			}).catch((err) => {
				console.log(err)
			});
		},
		resize() {
			setTimeout(() => {
				this.$options.chart.resize();
				if (JSON.stringify(this.$options.chartData) != '{}') {
					this.setData(this.$options.chartData);
				}
			}, 300)
		}
	},
	mounted() {
		// 基于准备好的dom，初始化echarts实例
		this.$options.chart = echarts.init(this.$refs.chart);

		window.addEventListener('resize', this.resize);
	},
	destroyed() {
		window.removeEventListener('resize', this.resize);
	}
}
</script>

<style scoped>
</style>